pub fn delete<B: ResourcesBackend>(
backend: &B,
uuid: &str,
) -> Result<(), ClientError>Expand description
Deletes a route by id.
Errors
If there is no token, the server cannot be reached, or it refuses the delete.
pub fn delete<B: ResourcesBackend>(
backend: &B,
uuid: &str,
) -> Result<(), ClientError>Deletes a route by id.
If there is no token, the server cannot be reached, or it refuses the delete.