pub fn save<B: ResourcesBackend>(
backend: &B,
route: &Route,
) -> Result<(), ClientError>Expand description
Creates or replaces route at its own id.
Errors
If there is no token, the server cannot be reached, or it refuses the write.
pub fn save<B: ResourcesBackend>(
backend: &B,
route: &Route,
) -> Result<(), ClientError>Creates or replaces route at its own id.
If there is no token, the server cannot be reached, or it refuses the write.